    <?php 

$lang['Attributes'] = 'Attributes';

$lang['edit_action_save'] = 'Save changes';
$lang['edit_action_cancel'] = 'Cancel';

$lang['msg_saved'] = 'Saved';
$lang['msg_error'] = 'Data not saved';
$lang['msg_required_fields'] = 'Required fields:<br />';

$lang['back_to_list'] = 'Back to list';

$lang['ln_del'] = 'Delete';
$lang['ln_del_image'] = 'Delete image';
$lang['ln_crop'] = 'Crop';
$lang['confirm_del'] = 'You confirm removal?';
$lang['ln_select_photos'] = 'Upload';
$lang['title_crop_dialog'] = 'Crop image. Recommended sizes: %s x %s. Current sizes: ';
$lang['btn_cancel'] = 'Cancel';
$lang['folder_error'] = 'Folder "%s" for field "%s" does not exist. Please create a new folder and try again.';