<?php 

$lang['Attributes'] = 'Атрибути';

$lang['edit_action_save'] = 'Зберегти зміни';
$lang['edit_action_cancel'] = 'Відміна';

$lang['msg_saved'] = 'Збережено';
$lang['msg_error'] = 'Дані не збережені';
$lang['msg_required_fields'] = 'Необхідно заповнити:<br />';

$lang['back_to_list'] = 'Повернутись до списку';


$lang['ln_del'] = 'Видалити';
$lang['ln_del_image'] = 'Видалити зображення';
$lang['ln_crop'] = 'Обрiзати';
$lang['confirm_del'] = 'Ви підтверджуєте видалення?';
$lang['ln_select_photos'] = 'Загрузити';
$lang['title_crop_dialog'] = 'Обрiзка зображення. Рекомендований розмiр: %s x %s. Поточнi розмiри: ';
$lang['btn_cancel'] = 'Скасувати';
$lang['folder_error'] = 'Папка "%s" для поля "%s" не існує. Будь ласка, створіть папку і повторіть спробу.';