<?php 

$lang['select_all'] = 'Все';

$lang['search_btn'] = 'Поиск';
$lang['clear_btn'] = 'Очистить';

$lang['btn_delete_text'] = 'Удалить';
$lang['btn_edit_text'] = 'Редактировать';
$lang['btn_add_text'] = 'Добавить';
$lang['btn_action_text'] = 'Действия';

$lang['msg_delete_data'] = 'Удалить текущую запись?';
$lang['folder_error'] = 'Папка "%s" для поля "%s" не существует. Пожалуйста, создайте папку и повторите попытку.';
