<?php 

$lang['Attributes'] = 'Атрибуты';

$lang['edit_action_save'] = 'Сохранить';
$lang['edit_action_cancel'] = 'Отмена';

$lang['msg_saved'] = 'Сохранено';
$lang['msg_error'] = 'Ошибка сохранения.';
$lang['msg_required_fields'] = 'Необходимо заполнить:<br />';

$lang['back_to_list'] = 'Вернутся к списку';


$lang['ln_del'] = 'Удалить';
$lang['ln_del_image'] = 'Удалить изображение';
$lang['ln_crop'] = 'Обрезать';
$lang['confirm_del'] = 'Вы подтверждаете удаление?';
$lang['ln_select_photos'] = 'Загрузить';
$lang['title_crop_dialog'] = 'Обрезка изображения. Рекомендованные размеры: %s x %s. Текущие размеры: ';
$lang['btn_cancel'] = 'Отменить';
$lang['folder_error'] = 'Папка "%s" для поля "%s" не существует. Пожалуйста, создайте папку и повторите попытку.';

